@@ -40,7 +40,7 @@ use warnings::unused;
 
 our @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.43.11'; # our $VERSION = '';
+$VERSION = '0.43.12'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -601,7 +601,7 @@ __END__
 
 =head1 NAME
 
-Sim::OPT.
+Sim::OPT::Descend.
 
 =head1 SYNOPSIS
 
@@ -612,7 +612,7 @@ Sim::OPT.
 
 Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent. It closes the loop formed by Sim::OPT -> Sim::OPT::Morph -> Sim::OPT::Sim -> Sim::OPT::Report::retrieve -> Sim::OPT::Report::report -> Sim::OPT::Descent -> Sim::OPT, which repeats at every block search cycle. It is a circularly recursive loop. 
 
-The objective function for rating the performances of the candidate solutions can be obtained by weighting objective functions (performance indicators) derived by the Sim::OPT::Report module.
+The objective function for rating the performances of the candidate solutions can be obtained by the weighting of objective functions (performance indicators) performed by the Sim::OPT::Report module, which follows user-specified criteria.
 
 =head2 EXPORT
 
@@ -620,7 +620,7 @@ The objective function for rating the performances of the candidate solutions ca
 
 =head1 SEE ALSO
 
-Annotated examples can be found in the "examples" directory in this distribution. They constitute the available documentation. Additionally, reference to the source code may be made.
+An example of configuration instructions for Sim::OPT::Descend is included in the comments in the "esp.pl" file, which is packed in "optw.tar.gz" file in "examples" directory in this distribution. But mostly, reference to the source code should be made.
 
 =head1 AUTHOR
 
