@@ -1362,7 +1362,7 @@ __END__
 
 =head1 NAME
 
-Sim::OPT.
+Sim::OPT::report.
 
 =head1 SYNOPSIS
 
@@ -1371,7 +1371,7 @@ Sim::OPT.
 
 =head1 DESCRIPTION
 
-Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results. Sim::OPT::Report performs two kinds of action. The first, which is required only by certain simulation programs, is that of managing the simulation program to make it write the results in a user-specified text format. This functionality is platform-specific and is presently implemented only for ESP-r. EnergyPlus does not require this functionality. New lines of code may have to be written for other platforms. The second functionality is that of gathering the results in a user-specified manner. This functionality is based on pattern-matching and is not platform-specific.
+Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results. Sim::OPT::Report performs two kinds of action. The first, which is required only by certain simulation programs, is that of making the simulation program write the results in a user-specified text format. This functionality is platform-specific and is presently implemented only for ESP-r (EnergyPlus does not require that). The second functionality is that of gathering the results in a user-specified manner. That functionality is based on pattern-matching and is not platform-specific.
 
 =head2 EXPORT
 
@@ -1379,7 +1379,7 @@ Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.
 
 =head1 SEE ALSO
 
-Annotated examples can be found in the "examples" directory in this distribution. They constitute the available documentation. Additionally, reference to the source code may be made.
+Two annotated examples ("esp.pl" for ESP-r and "ep.pl" for EnergyPlus) can be found packed in the "optw.tar.gz" file in "examples" directory in this distribution. They constitute the available documentation. Additionally, reference to the source code may be made.
 
 =head1 AUTHOR
 
