@@ -43,7 +43,7 @@ use warnings::unused;
 
 our @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.49.1'; # our $VERSION = '';
+$VERSION = '0.50.00'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Sim is the module used by Sim::OPT to launch simulations once the models have been built.'; 
 
 #########################################################################################
@@ -570,7 +570,7 @@ __END__
 
 =head1 NAME
 
-Sim::OPT.
+Sim::OPT::Sim.
 
 =head1 SYNOPSIS
 
@@ -579,7 +579,7 @@ Sim::OPT.
 
 =head1 DESCRIPTION
 
-Sim::OPT::Sim is the module used by Sim::OPT to launch the simulation once the models have been built. Sim::OPT::Sim's existing functionalities can be used to launch simulations in ESP-r and EnergyPlus. The possibility to call programs other from those two may be pursued through (small or substantial, depending from situation) modifications of the lines of code dedicated to the EnergyPlus platform.
+Sim::OPT::Sim is the module used by Sim::OPT to launch the simulations once the models have been built. Sim::OPT::Sim's presently existing functionalities can be used to launch simulations in ESP-r and EnergyPlus. The possibility to call simulation programs other than the cited two may be pursued through modifications of the code dedicated to EnergyPlus (which is actually meant as an example of a generic case). This portion of code may be actually constituted by the single line launching the simulation program through the shell.
 
 =head2 EXPORT
 
@@ -587,7 +587,7 @@ Sim::OPT::Sim is the module used by Sim::OPT to launch the simulation once the m
 
 =head1 SEE ALSO
 
-Annotated examples can be found in the "examples" directory in this distribution. They constitute the available documentation. Additionally, reference to the source code may be made.
+Two annotated examples ("esp.pl" for ESP-r and "ep.pl" for EnergyPlus) can be found packed in the "optw.tar.gz" file in "examples" directory in this distribution. They constitute the available documentation. Additionally, reference to the source code may be made.
 
 =head1 AUTHOR
 
